==> sight_21.1.1.orig.tar.gz: sight-21.1.1/modules/io/itk/test/tu/IoItkTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2021 IRCAD France
 * Copyright (C) 2012-2015 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::module::io::itk
{

namespace ut
{

/**
 * @brief Test many methods to create mesh.
 */
class IoItkTest : public CPPUNIT_NS::TestFixture
{
CPPUNIT_TEST_SUITE(IoItkTest);
CPPUNIT_TEST(testImageWriterJPG);
CPPUNIT_TEST(testImageSeriesWriterJPG);
CPPUNIT_TEST(testSaveLoadInr);
CPPUNIT_TEST(ImageSeriesInrTest);
CPPUNIT_TEST(SeriesDBInrTest);
CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp();
    void tearDown();

    void testImageWriterJPG();
    void testImageSeriesWriterJPG();
    void testSaveLoadInr();
    void ImageSeriesInrTest();
    void SeriesDBInrTest();
};

} //namespace ut

} //namespace sight::module::io::itk

==> sight_23.1.0.orig.tar.gz: sight-23.1.0/modules/io/itk/test/tu/IoItkTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2022 IRCAD France
 * Copyright (C) 2012-2015 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::module::io::itk::ut
{

/**
 * @brief Test many methods to create mesh.
 */
class IoItkTest : public CPPUNIT_NS::TestFixture
{
CPPUNIT_TEST_SUITE(IoItkTest);
CPPUNIT_TEST(testImageSeriesWriterJPG);
CPPUNIT_TEST(testSaveLoadInr);
CPPUNIT_TEST(testSaveLoadNifti);
CPPUNIT_TEST(ImageSeriesInrTest);
CPPUNIT_TEST(ImageSeriesNiftiTest);
CPPUNIT_TEST(SeriesSetInrTest);
CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp() override;
    void tearDown() override;

    static void testImageSeriesWriterJPG();
    static void testSaveLoadInr();
    static void testSaveLoadNifti();
    static void ImageSeriesInrTest();
    static void ImageSeriesNiftiTest();
    static void SeriesSetInrTest();
};

} // namespace sight::module::io::itk::ut
